@@ -79,6 +79,11 @@ class SetupInfo(clcommands.Command):
                  "for the value found in debian/changelog",
                  'group': 'Default',
                 }),
+               ('rpm',
+                {'action': 'store_true',
+                 'dest': 'rpm',
+                 'help': 'build a rpm package instead of deb',
+                }),
                ('arch',
                 {'type': 'csv',
                  'dest': 'archi',
@@ -290,7 +295,8 @@ class SetupInfo(clcommands.Command):
                 except IOError, err:
                     raise LGPException(err)
             cmdline = Template(cmd)
-            cmdline = cmdline.substitute(setup=self.config.setup_file, **args)
+            setup_file = self._normpath(self.config.setup_file)
+            cmdline = cmdline.substitute(setup=setup_file, **args)
         self.logger.debug('run subprocess command: %s' % cmdline)
         if args:
             self.logger.debug('command substitutions: %s' % args)
